==> rabbit-client-2.9.1b1.tar.gz: rabbit-client-2.9.1b1/rabbit/cli/consumer.py <==
import asyncio

from rabbit.client import AioRabbitClient
from rabbit.exchange import Exchange
from rabbit.job import async_chaos_job, async_echo_job
from rabbit.logger import logger
from rabbit.queue import Queue
from rabbit.subscribe import Subscribe


class Consumer:
    def __init__(
        self,
        host: str,
        port: int,
        login: str,
        password: str,
        exchange_name: str,
        exchange_type: str,
        exchange_topic: str,
        queue_name: str,
        concurrent: int,
    ):
        self.loop = asyncio.get_event_loop()
        self.subscribe_client = AioRabbitClient()
        self.loop.create_task(
            self.subscribe_client.persistent_connect(
                host=host, port=port, login=login, password=password
            )
        )
        self.exchange_type = exchange_type
        self.exchange_topic = exchange_topic
        self.exchange_name = exchange_name
        self.queue_name = queue_name
        self.concurrent = concurrent

    async def init(self, task, verbose: bool = False):
        logger.info(f"Using {task.__doc__}")
        subscribe = Subscribe(
            client=self.subscribe_client,
            task=task,
            exchange=Exchange(
                self.exchange_name, self.exchange_type, self.exchange_topic
            ),
            queue=Queue(name=self.queue_name),
            concurrent=self.concurrent,
        )
        await subscribe.configure()
        if verbose:
            while True:
                await asyncio.sleep(10)
                logger.debug(repr(self.subscribe_client))
                for ch in self.subscribe_client.protocol.channels.values():
                    logger.debug(f"Channel is open: {ch.is_open}")

    def run(self, chaos_mode: bool = False, verbose: bool = True):
        task = async_echo_job
        if chaos_mode:
            task = async_chaos_job
        self.loop.run_until_complete(self.init(task, verbose))
        self.loop.run_forever()

==> rabbit-client-3.3.0.tar.gz: rabbit-client-3.3.0/rabbit/cli/consumer.py <==
import asyncio

from rabbit.client import AioRabbitClient
from rabbit.exchange import Exchange
from rabbit.job import async_chaos_job, async_echo_job
from rabbit.logger import logger
from rabbit.queue import Queue
from rabbit.subscribe import Subscribe


class Consumer:
    def __init__(
        self,
        host: str,
        port: int,
        login: str,
        password: str,
        exchange_name: str,
        exchange_type: str,
        exchange_topic: str,
        queue_name: str,
        concurrent: int,
    ) -> None:
        self.subscribe_client = AioRabbitClient()

        self._loop = self.event_loop()  # type: ignore
        self._loop.create_task(
            self.subscribe_client.persistent_connect(
                host=host, port=port, login=login, password=password
            ),
            name="rabbit-client-cli-connection",
        )

        self.exchange_type = exchange_type
        self.exchange_topic = exchange_topic
        self.exchange_name = exchange_name
        self.queue_name = queue_name
        self.concurrent = concurrent

    def event_loop(self):
        try:
            loop = asyncio.get_running_loop()
        except RuntimeError:
            loop = asyncio.new_event_loop()
        return loop

    def run(self, chaos_mode: bool = False, verbose: bool = True) -> None:
        task = async_echo_job
        if chaos_mode:
            task = async_chaos_job

        self._loop.run_until_complete(self.init(task, verbose))
        self._loop.run_forever()

    async def init(self, task, verbose: bool = False) -> None:
        logger.info(f"Using '{task.__doc__}'")
        subscribe = Subscribe(
            task=task,
            exchange=Exchange(
                self.exchange_name, self.exchange_type, self.exchange_topic
            ),
            queue=Queue(name=self.queue_name),
            concurrent=self.concurrent,
        )
        await self.subscribe_client.register(subscribe)
        if verbose:
            while True:
                await asyncio.sleep(10)
                logger.debug(repr(self.subscribe_client))
